Module chunking

Module chunking 

Pluggable chunking algorithms and default sliding-window implementation. Pluggable chunking algorithms.

ChunkingAlgorithm defines the extension point used by the sampler to materialize chunk candidates from record sections.

Structs

SlidingWindowChunker
Default sliding-window chunking algorithm.

Traits

ChunkingAlgorithm
Pluggable algorithm for materializing chunks from a record section.