Generic configurable filesystem-backed source implementation.
Structs
- File
Source - Generic filesystem-backed source with configurable taxonomy and section mapping.
- File
Source Config - Configuration for a generic filesystem-backed data source.
Functions
- anchor_
context_ sections - Build a default two-section payload of title anchor and body context.
- default_
title_ context_ triplet_ recipes - Default mixed-negative recipes used by
FileSourcetitle/body corpora. - taxonomy_
from_ path - Build default taxonomy from the file path relative to
root.
Type Aliases
- Section
Builder - Builds record sections from a normalized title and body.
- Taxonomy
Builder - Builds taxonomy values from a root path and file path.