pub struct SourceSnapshot {
pub records: Vec<DataRecord>,
pub cursor: SourceCursor,
}Expand description
Result of a single source refresh call.
Pass the returned cursor back into the next refresh to continue paging.
Fields
records: Vec<DataRecord>Records returned by the refresh operation.
cursor: SourceCursorNext cursor to pass into a future refresh call.