pub trait ChunkingAlgorithm: Send + Sync {
// Required method
fn materialize(
&self,
strategy: &ChunkingStrategy,
record: &DataRecord,
section_idx: usize,
section: &RecordSection,
) -> Vec<RecordChunk>;
}Expand description
Pluggable algorithm for materializing chunks from a record section.
Required Methods
Sourcefn materialize(
&self,
strategy: &ChunkingStrategy,
record: &DataRecord,
section_idx: usize,
section: &RecordSection,
) -> Vec<RecordChunk>
fn materialize( &self, strategy: &ChunkingStrategy, record: &DataRecord, section_idx: usize, section: &RecordSection, ) -> Vec<RecordChunk>
Produce candidate chunks for one section of a record.