Module file_source

Module file_source 

Generic configurable filesystem-backed source implementation.

Structs

FileSource
Generic filesystem-backed source with configurable taxonomy and section mapping.
FileSourceConfig
Configuration for a generic filesystem-backed data source.

Functions

anchor_context_sections
Build a default two-section payload of title anchor and body context.
default_title_context_triplet_recipes
Default mixed-negative recipes used by FileSource title/body corpora.
taxonomy_from_path
Build default taxonomy from the file path relative to root.

Type Aliases

SectionBuilder
Builds record sections from a normalized title and body.
TaxonomyBuilder
Builds taxonomy values from a root path and file path.